Enum git_testament::CommitKind [−][src]
pub enum CommitKind<'a> {
NoRepository(&'a str, &'a str),
NoCommit(&'a str, &'a str),
NoTags(&'a str, &'a str),
FromTag(&'a str, &'a str, &'a str, usize),
}Expand description
The kind of commit available at the point that the testament was created.
Variants
No repository was present. Instead the crate’s version and the build date are recorded.
No commit was present, though it was a repository. Instead the crate’s version and the build date are recorded.
There are no tags in the repository in the history of the commit. The commit hash and commit date are recorded.
There were tags in the history of the commit. The tag name, commit hash, commit date, and distance from the tag to the commit are recorded.