Enum git_testament::GitModification[][src]

pub enum GitModification<'a> {
    Added(&'a [u8]),
    Removed(&'a [u8]),
    Modified(&'a [u8]),
    Untracked(&'a [u8]),
}
A modification to a working tree, recorded when the testament was created.

Variants

Added(&'a [u8])

A file or directory was added but not committed

Tuple Fields of Added

0: &'a [u8]
Removed(&'a [u8])

A file or directory was removed but not committed

Tuple Fields of Removed

0: &'a [u8]
Modified(&'a [u8])

A file was modified in some way, either content or permissions

Tuple Fields of Modified

0: &'a [u8]
Untracked(&'a [u8])

A file or directory was present but untracked

Tuple Fields of Untracked

0: &'a [u8]